@@ -100,30 +100,12 @@ int computeCursorXPos(int cursor, int hexOrAscii)
 /*******************************************************************************/
 /* Curses functions */
 /*******************************************************************************/
-static void handleSigWinch(int sig)
-{
-  /*Close and refresh window to get new size*/
-  endwin();
-  refresh();
-
-  /*Reset to trigger recalculation*/
-  lineLength = 0;
-
-  clear();
-  initDisplay();
-  readFile();
-  display();
-}
 
 void initCurses(void)
 {
   struct sigaction sa;
   initscr();
 
-  memset(&sa, 0, sizeof(struct sigaction));
-  sa.sa_handler = handleSigWinch;
-  sigaction(SIGWINCH, &sa, NULL);
-
 #ifdef HAVE_COLORS
   if (colored) {
     start_color();
@@ -182,6 +164,7 @@ void exitCurses(void)
 
 void display(void)
 {
+  long long fsize;
   int i;
 
   for (i = 0; i < nbBytes; i += lineLength) {
@@ -204,8 +187,9 @@ void display(void)
   else if (edited) i = '*';
   else i = '-';
   printw("-%c%c  %s       --0x%llX", i, i, baseName, (long long) base + cursor);
-  if (MAX(fileSize, lastEditedLoc)) printw("/0x%llX", (long long) getfilesize());
-  printw("--%i%%", 100 * (base + cursor + getfilesize()/200) / getfilesize() );
+  fsize = getfilesize();
+  if (MAX(fileSize, lastEditedLoc)) printw("/0x%llX", fsize);
+  printw("--%i%%", fsize == 0 ? 0 : 100 * (base + cursor + fsize/200) / fsize );
   if (mode == bySector) printw("--sector %lld", (long long) ((base + cursor) / SECTOR_SIZE));
 
   move(cursor / lineLength, computeCursorXCurrentPos());
